==> tuia-commercial-center-api-0.0.4-20190613.032719-4-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/CouponsCodeBatchInfoDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto;

import cn.com.duiba.tuia.commercial.center.api.common.BaseDto;

public class CouponsCodeBatchInfoDto extends BaseDto {

    private static final long serialVersionUID = 3L;

    /** 批次ID */
    private Long              id;

    /** couponsValidity:劵码开始有效期. */
    private String            validStartDate;

    /** couponsValidity:劵码结束有效期. */
    private String            validEndDate;

    /** couponsCode:劵码编号. */
    private String            couponsCode;

    /** couponsPwd:劵码密码. */
    private String            couponsPwd;

    /** linkInfo:链接. */
    private String            linkInfo;

    private Long              stock;

    private Long              stockChange;

    private String            stockId;

    /**直投页id */
    private Long              pageId;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCouponsCode() {
        return couponsCode;
    }

    public void setCouponsCode(String couponsCode) {
        this.couponsCode = couponsCode;
    }

    public String getCouponsPwd() {
        return couponsPwd;
    }

    public void setCouponsPwd(String couponsPwd) {
        this.couponsPwd = couponsPwd;
    }

    public String getLinkInfo() {
        return linkInfo;
    }

    public void setLinkInfo(String linkInfo) {
        this.linkInfo = linkInfo;
    }

    public String getValidStartDate() {
        return validStartDate;
    }

    public void setValidStartDate(String validStartDate) {
        this.validStartDate = validStartDate;
    }

    public String getValidEndDate() {
        return validEndDate;
    }

    public void setValidEndDate(String validEndDate) {
        this.validEndDate = validEndDate;
    }

    public Long getStock() {
        return stock;
    }

    public void setStock(Long stock) {
        this.stock = stock;
    }

    public Long getStockChange() {
        return stockChange;
    }

    public void setStockChange(Long stockChange) {
        this.stockChange = stockChange;
    }

    public String getStockId() {
        return stockId;
    }

    public void setStockId(String stockId) {
        this.stockId = stockId;
    }

    public Long getPageId() {
        return pageId;
    }

    public void setPageId(Long pageId) {
        this.pageId = pageId;
    }
}

==> tuia-commercial-center-api-0.0.4-20190711.091300-8-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/CouponsCodeBatchInfoDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto;

import cn.com.duiba.tuia.commercial.center.api.dto.common.BaseDto;

public class CouponsCodeBatchInfoDto extends BaseDto {

    private static final long serialVersionUID = 3L;

    /** 批次ID */
    private Long              id;

    /** couponsValidity:劵码开始有效期. */
    private String            validStartDate;

    /** couponsValidity:劵码结束有效期. */
    private String            validEndDate;

    /** couponsCode:劵码编号. */
    private String            couponsCode;

    /** couponsPwd:劵码密码. */
    private String            couponsPwd;

    /** linkInfo:链接. */
    private String            linkInfo;

    private Long              stock;

    private Long              stockChange;

    private String            stockId;

    /**直投页id */
    private Long              pageId;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCouponsCode() {
        return couponsCode;
    }

    public void setCouponsCode(String couponsCode) {
        this.couponsCode = couponsCode;
    }

    public String getCouponsPwd() {
        return couponsPwd;
    }

    public void setCouponsPwd(String couponsPwd) {
        this.couponsPwd = couponsPwd;
    }

    public String getLinkInfo() {
        return linkInfo;
    }

    public void setLinkInfo(String linkInfo) {
        this.linkInfo = linkInfo;
    }

    public String getValidStartDate() {
        return validStartDate;
    }

    public void setValidStartDate(String validStartDate) {
        this.validStartDate = validStartDate;
    }

    public String getValidEndDate() {
        return validEndDate;
    }

    public void setValidEndDate(String validEndDate) {
        this.validEndDate = validEndDate;
    }

    public Long getStock() {
        return stock;
    }

    public void setStock(Long stock) {
        this.stock = stock;
    }

    public Long getStockChange() {
        return stockChange;
    }

    public void setStockChange(Long stockChange) {
        this.stockChange = stockChange;
    }

    public String getStockId() {
        return stockId;
    }

    public void setStockId(String stockId) {
        this.stockId = stockId;
    }

    public Long getPageId() {
        return pageId;
    }

    public void setPageId(Long pageId) {
        this.pageId = pageId;
    }
}
